@@ -3,11 +3,13 @@ import six
 import time
 import pandas as pd
 import numpy as np
+from pathlib import Path
+from warnings import warn
 from symengine import Add, sympify
 from dexom_python.enum_functions.icut_functions import create_icut_constraint
 from dexom_python.imat_functions import imat
 from dexom_python.result_functions import read_solution
-from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options
+from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options, DEFAULT_VALUES
 from dexom_python.enum_functions.enumeration import EnumSolution, get_recent_solution_and_iteration, create_enum_variables
 
 
@@ -86,8 +88,8 @@ def create_maxdist_objective(model, reaction_weights, prev_sol, prev_sol_bin, on
     return objective
 
 
-def maxdist(model, reaction_weights, prev_sol=None, eps=1e-4, thr=1e-4, obj_tol=1e-3, maxiter=10, icut=True, full=False,
-            only_ones=False):
+def maxdist(model, reaction_weights, prev_sol=None, eps=DEFAULT_VALUES['epsilon'], thr=DEFAULT_VALUES['threshold'],
+            obj_tol=DEFAULT_VALUES['obj_tol'], maxiter=DEFAULT_VALUES['maxiter'], icut=True, full=False, only_ones=False):
     """
 
     Parameters
@@ -155,52 +157,68 @@ def maxdist(model, reaction_weights, prev_sol=None, eps=1e-4, thr=1e-4, obj_tol=
     return solution
 
 
-if __name__ == '__main__':
+def main():
+    """
+    This function is called when you run this script from the commandline.
+    It performs the distance-maximization enumeration algorithm
+    Use --help to see commandline parameters
+    """
     description = 'Performs the distance-maximization enumeration algorithm'
-
     parser = argparse.ArgumentParser(description=description, formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('-m', '--model', help='Metabolic model in sbml, matlab, or json format')
     parser.add_argument('-r', '--reaction_weights', default=None,
                         help='Reaction weights in csv format (first row: reaction names, second row: weights)')
     parser.add_argument('-p', '--prev_sol', default=[], help='starting solution or directory of recent solutions')
-    parser.add_argument('-e', '--epsilon', type=float, default=1e-4,
+    parser.add_argument('-e', '--epsilon', type=float, default=DEFAULT_VALUES['epsilon'],
                         help='Activation threshold for highly expressed reactions')
-    parser.add_argument('--threshold', type=float, default=1e-4, help='Activation threshold for all reactions')
-    parser.add_argument('-t', '--timelimit', type=int, default=None, help='Solver time limit')
-    parser.add_argument('-i', '--maxiter', type=int, default=10, help='Iteration limit')
-    parser.add_argument('--tol', type=float, default=1e-7, help='Solver feasibility tolerance')
-    parser.add_argument('--mipgap', type=float, default=1e-3, help='Solver MIP gap tolerance')
-    parser.add_argument('--obj_tol', type=float, default=1e-3,
+    parser.add_argument('--threshold', type=float, default=DEFAULT_VALUES['threshold'],
+                        help='Activation threshold for all reactions')
+    parser.add_argument('-t', '--timelimit', type=int, default=DEFAULT_VALUES['timelimit'], help='Solver time limit')
+    parser.add_argument('--tol', type=float, default=DEFAULT_VALUES['tolerance'], help='Solver feasibility tolerance')
+    parser.add_argument('--mipgap', type=float, default=DEFAULT_VALUES['mipgap'], help='Solver MIP gap tolerance')
+    parser.add_argument('--obj_tol', type=float, default=DEFAULT_VALUES['obj_tol'],
                         help='objective value tolerance, as a fraction of the original value')
+    parser.add_argument('-i', '--maxiter', type=int, default=DEFAULT_VALUES['maxiter'], help='Iteration limit')
     parser.add_argument('-o', '--output', default='div_enum', help='Base name of output files, without format')
     parser.add_argument('--noicut', action='store_true', help='Use this flag to remove the icut constraint')
     parser.add_argument('--full', action='store_true', help='Use this flag to assign non-zero weights to all reactions')
+    parser.add_argument('--onlyones', action='store_true', help='Use this flag for the old implementation of maxdist')
     args = parser.parse_args()
 
     model = read_model(args.model)
     check_model_options(model, timelimit=args.timelimit, feasibility=args.tol, mipgaptol=args.mipgap)
-
     reaction_weights = {}
     if args.reaction_weights is not None:
         reaction_weights = load_reaction_weights(args.reaction_weights)
 
-    a = args.dist_anneal
-    if '.' in args.prev_sol:
-        prev_sol, prev_bin = read_solution(args.prev_sol, model)
-        model = create_enum_variables(model, reaction_weights, eps=args.epsilon, thr=args.threshold, full=args.full)
-    elif args.prev_sol is not None:
-        prev_sol, i = get_recent_solution_and_iteration(args.prev_sol, args.startsol_num)
-        a = a ** i
-        model = create_enum_variables(model, reaction_weights, eps=args.epsilon, thr=args.threshold, full=args.full)
-    else:
+    prev_sol_success = False
+    if args.prev_sol is not None:
+        prev_sol_path = Path(args.prev_sol)
+        if prev_sol_path.is_file():
+            prev_sol, prev_bin = read_solution(args.prev_sol, model)
+            model = create_enum_variables(model, reaction_weights, eps=args.epsilon, thr=args.threshold, full=args.full)
+            prev_sol_success = True
+        elif prev_sol_path.is_dir():
+            try:
+                prev_sol, i = get_recent_solution_and_iteration(args.prev_sol, args.startsol_num)
+            except:
+                warn('Could not find solution in directory %s, computing new starting solution' % args.prev_sol)
+            else:
+                model = create_enum_variables(model, reaction_weights, eps=args.epsilon, thr=args.threshold,
+                                              full=args.full)
+                prev_sol_success = True
+        else:
+            warn('Could not read previous solution at path %s, computing new starting solution' % args.prev_sol)
+    if not prev_sol_success:
         prev_sol = imat(model, reaction_weights, epsilon=args.epsilon, threshold=args.threshold)
-
     icut = False if args.noicut else True
-    save = True if args.save else False
-    full = True if args.full else False
-
     maxdist_sol = maxdist(model=model, reaction_weights=reaction_weights, prev_sol=prev_sol, eps=args.epsilon,
                           thr=args.threshold, obj_tol=args.obj_tol, maxiter=args.maxiter, icut=icut, full=args.full,
-                          only_ones=False)
+                          only_ones=args.onlyones)
     sol = pd.DataFrame(maxdist_sol.binary)
     sol.to_csv(args.output+'_solutions.csv')
+    return True
+
+
+if __name__ == '__main__':
+    main()
