@@ -3,7 +3,7 @@ import os
 import pandas as pd
 import numpy as np
 from dexom_python.imat_functions import imat
-from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options
+from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options, DEFAULT_VALUES
 from dexom_python.result_functions import read_solution, write_solution
 from dexom_python.enum_functions.enumeration import create_enum_variables
 from warnings import warn
@@ -21,8 +21,8 @@ class RxnEnumSolution(object):
         self.objective_value = objective_value
 
 
-def rxn_enum(model, reaction_weights, prev_sol=None, rxn_list=[], eps=1e-4, thr=1e-4, obj_tol=1e-3, out_path='enum_rxn',
-             save=False):
+def rxn_enum(model, reaction_weights, prev_sol=None, rxn_list=[], eps=DEFAULT_VALUES['epsilon'],
+             thr=DEFAULT_VALUES['threshold'], obj_tol=DEFAULT_VALUES['obj_tol'], out_path='enum_rxn', save=False):
     """
     Reaction enumeration method
 
@@ -137,9 +137,13 @@ def rxn_enum(model, reaction_weights, prev_sol=None, rxn_list=[], eps=1e-4, thr=
     return solution
 
 
-if __name__ == '__main__':
-    description = 'Performs the reaction enumeration algorithm on a specified list of reactions'
-
+def main():
+    """
+    This function is called when you run this script from the commandline.
+    It performs the reaction-enumeration algorithm on a specified list of reactions
+    Use --help to see commandline parameters
+    """
+    description = 'Performs the reaction-enumeration algorithm on a specified list of reactions'
     parser = argparse.ArgumentParser(description=description, formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('-m', '--model', help='Metabolic model in sbml, matlab, or json format')
     parser.add_argument('-l', '--reaction_list', default=None, help='csv list of reactions to enumerate - if empty, '
@@ -149,13 +153,14 @@ if __name__ == '__main__':
     parser.add_argument('-r', '--reaction_weights', default=None,
                         help='Reaction weights in csv format (first row: reaction names, second row: weights)')
     parser.add_argument('-p', '--prev_sol', default=None, help='initial imat solution in .txt format')
-    parser.add_argument('-e', '--epsilon', type=float, default=1e-2,
+    parser.add_argument('-e', '--epsilon', type=float, default=DEFAULT_VALUES['epsilon'],
                         help='Activation threshold for highly expressed reactions')
-    parser.add_argument('--threshold', type=float, default=1e-5, help='Activation threshold for all reactions')
-    parser.add_argument('-t', '--timelimit', type=int, default=None, help='Solver time limit')
-    parser.add_argument('--tol', type=float, default=1e-7, help='Solver feasibility tolerance')
-    parser.add_argument('--mipgap', type=float, default=1e-3, help='Solver MIP gap tolerance')
-    parser.add_argument('--obj_tol', type=float, default=1e-3,
+    parser.add_argument('--threshold', type=float, default=DEFAULT_VALUES['threshold'],
+                        help='Activation threshold for all reactions')
+    parser.add_argument('-t', '--timelimit', type=int, default=DEFAULT_VALUES['timelimit'], help='Solver time limit')
+    parser.add_argument('--tol', type=float, default=DEFAULT_VALUES['tolerance'], help='Solver feasibility tolerance')
+    parser.add_argument('--mipgap', type=float, default=DEFAULT_VALUES['mipgap'], help='Solver MIP gap tolerance')
+    parser.add_argument('--obj_tol', type=float, default=DEFAULT_VALUES['obj_tol'],
                         help='objective value tolerance, as a fraction of the original value')
     parser.add_argument('-o', '--output', default='rxn_enum', help='Path of output files, without format')
     parser.add_argument('--save', action='store_true', help='Use this flag to save each solution individually')
@@ -168,7 +173,6 @@ if __name__ == '__main__':
     if args.reaction_weights is not None:
         reaction_weights = load_reaction_weights(args.reaction_weights)
 
-    rxn_list = []
     if args.reaction_list is not None:
         df = pd.read_csv(args.reaction_list, header=None)
         reactions = [x for x in df.unstack().values]
@@ -194,7 +198,12 @@ if __name__ == '__main__':
         initial_solution = imat(model, reaction_weights, epsilon=args.epsilon, threshold=args.threshold)
 
     solution = rxn_enum(model=model, rxn_list=rxn_list, prev_sol=initial_solution, reaction_weights=reaction_weights,
-                        eps=args.epsilon, thr=args.threshold, obj_tol=args.obj_tol, out_path=args.output, save=args.save)
-
+                        eps=args.epsilon, thr=args.threshold, obj_tol=args.obj_tol, out_path=args.output,
+                        save=args.save)
     uniques = pd.DataFrame(solution.unique_binary)
-    uniques.to_csv(args.output+'_solutions.csv')
+    uniques.to_csv(args.output + '_solutions.csv')
+    return True
+
+
+if __name__ == '__main__':
+    main()
